@@ -4,11 +4,11 @@ import random
 import warnings
 from tqdm import tqdm
 import numpy as np
-from . import activation_function
-from . import basic_function
+from draft_basic import activation_function
+from draft_basic import basic_function
 
 class MLP:
-    def __init__(self, input_node_num, hidden_node_num, hidden_activation='relu', target='2_classify', output_node_num=1):
+    def __init__(self, input_node_num, hidden_node_num, hidden_activation='relu', target='2_classify', output_node_num=1, random_seed=None):
         self.input_node_num = input_node_num
         self.hidden_node_num = hidden_node_num
         self.output_node_num = output_node_num
@@ -18,18 +18,23 @@ class MLP:
             raise ValueError(f"隐藏层节点数量非法")
         if output_node_num < 1 or output_node_num != int(output_node_num):
             raise ValueError(f"输出层节点数量非法")
+        if random_seed is not None:
+            if not isinstance(random_seed, int):
+                raise ValueError(f"random_seed应该为一个整数")
+
+        self.rng = random.Random(random_seed)
 
         hidden_weight = []
         for i in range(hidden_node_num):
             weight_list = []
             for j in range(input_node_num + 1):
-                weight_list.append(random.random())
+                weight_list.append(self.rng.random())
             hidden_weight.append(weight_list)
         self.hidden_weight = hidden_weight
         if target == '2_classify' or target == 'output_1_node_regress':
             output_weight = []
             for i in range(hidden_node_num + 1):
-                output_weight.append(random.random())
+                output_weight.append(self.rng.random())
             self.output_weight = output_weight
         elif target == 'multi_classify' or target == 'output_multi_node_regress':
             output_weight = []
@@ -37,7 +42,7 @@ class MLP:
             for i in range(output_node_num):
                 weight_list = []
                 for j in range(hidden_node_num + 1):
-                    weight_list.append(random.random())
+                    weight_list.append(self.rng.random())
                 output_weight.append(weight_list)
             self.output_weight = output_weight
         else:
@@ -122,7 +127,7 @@ class MLP:
 
 
                 indices = list(range(len(x_train)))
-                random.shuffle(indices)
+                self.rng.shuffle(indices)
 
                 # 使用打乱的索引重新排序两个列表
                 x_random_train = [x_train[index] for index in indices]
@@ -278,7 +283,7 @@ class MLP:
                         text += f'学习率：{lr}，'
 
                 indices = list(range(len(x_train)))
-                random.shuffle(indices)
+                self.rng.shuffle(indices)
 
                 # 使用打乱的索引重新排序两个列表
                 x_random_train = [x_train[index] for index in indices]
@@ -460,7 +465,7 @@ class MLP:
                         text += f'学习率：{lr}，'
 
                 indices = list(range(len(x_train)))
-                random.shuffle(indices)
+                self.rng.shuffle(indices)
 
                 # 使用打乱的索引重新排序两个列表
                 x_random_train = [x_train[index] for index in indices]
@@ -601,7 +606,7 @@ class MLP:
                         text += f'学习率：{lr}，'
 
                 indices = list(range(len(x_train)))
-                random.shuffle(indices)
+                self.rng.shuffle(indices)
 
                 # 使用打乱的索引重新排序两个列表
                 x_random_train = [x_train[index] for index in indices]
